# Utility scripts

* `docker-neo4j.sh` is a bash scipt that allows you to run a neo4j instance with user supplied authentication
  credentials.

* `tests-with-docker-compose.sh` is a bash script that is used [during testing](../.github/workflows/integration-tests.yml)


